// server_env.hpp
//
// read the _server.env file and provide a class to access the variables
//

#ifndef __SERVER_ENV_HPP
#define __SERVER_ENV_HPP

#include <string>
#include <map>

namespace dropshell {

// reads path / _server.env and provides a class to access the variables.
// each env file is required to have the following variables:
// SSH_HOST
// SSH_USER
// SSH_PORT
// the following replacements are made in the values:
// ${USER} -> the username of the user running dropshell
class server_env {
    public:
        server_env(const std::string& path);
        std::string get_variable(const std::string& name);
        const std::map<std::string, std::string>& get_variables() const;

        std::string get_SSH_HOST();
        std::string get_SSH_USER();
        std::string get_SSH_PORT();

        std::string get_DROPSHELL_DIR();

        bool is_valid();

    private:
        std::map<std::string, std::string> variables;
        bool mValid;
};

} // namespace dropshell


#endif // __SERVER_ENV_HPP  